https://git.reactos.org/?p=reactos.git;a=commitdiff;h=e8b79e89ebada57f3ba3009152206dc70d7ada86

commit e8b79e89ebada57f3ba3009152206dc70d7ada86
Author:     Thomas Faber <thomas.fa...@reactos.org>
AuthorDate: Sat Oct 30 19:43:27 2021 -0400
Commit:     Thomas Faber <thomas.fa...@reactos.org>
CommitDate: Sat Nov 13 21:23:40 2021 -0500

    [NTOS:PS] Fix copypasta in NtQueryInformationJobObject. CID 1441354
---
 ntoskrnl/ps/job.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/ntoskrnl/ps/job.c b/ntoskrnl/ps/job.c
index 8b130010bfd..9526e2be0dc 100644
--- a/ntoskrnl/ps/job.c
+++ b/ntoskrnl/ps/job.c
@@ -546,10 +546,10 @@ NtQueryInformationJobObject (
                 ProbeForWrite(JobInformation, JobInformationLength, 
RequiredAlign);
             }
 
             /* But also return lenght if asked */
             if (ReturnLength != NULL)
             {
-                ProbeForWrite(JobInformation, sizeof(ULONG), sizeof(ULONG));
+                ProbeForWriteUlong(ReturnLength);
             }
         }
         _SEH2_EXCEPT(EXCEPTION_EXECUTE_HANDLER)
@@ -546,10 +546,10 @@ NtQueryInformationJobObject (
             }
 
-            /* But also return lenght if asked */
+            /* But also return length if asked */
             if (ReturnLength != NULL)
             {

Reply via email to